========================
Changelog for autopypath
========================

1.0.0 (2026-01-22)
------------------
- Official release of autopypath version 1.0.0.
- Finalized documentation and public API.
- Added detailed examples and usage instructions.
- Narrowed down and stabilized the public API.
- Removed unused pydeps dependency.
- Fixed display of Apache-2.0 license badge in index.rst
- Bumped version to 1.0.0.

0.9.1 (2026-01-21)
------------------------
- Added pre-commit Git hooks for code quality checks and formatting on commit.
- Updated index.rst and README.rst documentation.
- Bumped version to 0.9.1.

0.9.0 (2026-01-21)
------------------------
- Initial release for version 0.9.0 to PyPI
